@@ -7,7 +7,6 @@ def test_visit_webpage_basic() -> None:
     assert content.id == "https://example.com/"
     assert content.provider == "basic"
     assert "Example Domain" in content.text
-    assert "illustrative" in content.text
 
 
 def test_visit_webpage_exa() -> None:
@@ -16,7 +15,6 @@ def test_visit_webpage_exa() -> None:
     assert content.id == "https://example.com/"
     assert content.provider == "exa"
     assert "Example Domain" in content.text
-    assert "illustrative" in content.text
 
 
 def test_visit_webpage_pdf() -> None:
@@ -32,12 +30,6 @@ def test_visit_webpage_nature() -> None:
     assert "1002" in content.text
 
 
-def test_visit_webpage_github_issue() -> None:
-    url = "https://github.com/numpy/numpy/issues/10881"
-    content = visit_webpage(url, provider="tavily")
-    assert "on Apr 15, 2018" in str(content.text)
-
-
 def test_visit_webpage_exception() -> None:
     url = "https://www.researchgate.net/profile/Peter-Giovannini"
     content = visit_webpage(url)
